@@ -20,13 +20,18 @@ def intersection(obj1, obj2):
             if len(res) > 0:
                 return res
         elif isinstance(obj1, list) or isinstance(obj1, tuple):
-            mark = [0 for _ in range(len(obj2))]
             res = list()
-            for v in obj1:
-                for i in range(len(mark)):
-                    if mark[i] == 0 and equal(v, obj2[i]):
-                        mark[i] = 1
-                        res.append(v)
+            if len(obj1) == 1 and len(obj2) == 1:
+                ele = intersection(obj1[0], obj2[0])
+                if ele and len(ele):
+                    res.append(ele)
+            else:
+                mark = [0 for _ in range(len(obj2))]
+                for v in obj1:
+                    for i in range(len(mark)):
+                        if mark[i] == 0 and equal(v, obj2[i]):
+                            mark[i] = 1
+                            res.append(v)
             if len(res) > 0:
                 return res
         elif obj1 == obj2:
