@@ -37,4 +37,6 @@ def subtract(obj1, obj2):
             if obj1 == obj2:
                 return None
             return obj1
+    else:
+        return obj1
     return None
